@@ -1,14 +1,15 @@
 use v5.14;
 use warnings;
 
-package Jasonify v0.20.052;
+package Jasonify v0.20.060;
 # ABSTRACT: Just Another Serialized Object Notation library.
 
 
-use Carp             ();           #qw( carp );
-use Datify v0.20.052 ();
-use Scalar::Util     ();           #qw( blessed looks_like_number reftype );
-use String::Tools  qw( subst );    #qw( );
+use Carp                ();    #qw( carp );
+use Datify    v0.20.060 ();
+use LooksLike v0.20.060 ();    #qw( number representation );
+use Scalar::Util        ();    #qw( blessed reftype );
+use String::Tools       ();    #qw( subst );
 
 use parent 'Datify';
 
@@ -202,17 +203,14 @@ sub keyify {
     my $self = &Datify::self;
     local $_ = shift if @_;
 
-    return Scalar::Util::looks_like_number($_)
-        ? (
-            defined( $_ <=> 0 )
-                ? (
-                      $_ ==  "Infinity" ? $Jasonify::Number::inf
-                    : $_ == "-Infinity" ? $Jasonify::Number::ninf
-                    :                     $self->stringify($_)
-                )
-                : $Jasonify::Number::nan
-        )
-        : $self->stringify($_);
+    return LooksLike::representation(
+        $_,
+
+        $_          => $self->stringify($_),
+        "infinity"  => $Jasonify::Number::inf,
+        "-infinity" => $Jasonify::Number::ninf,
+        "nan"       => $Jasonify::Number::nan,
+    );
 }
 
 sub _objectify_via {
@@ -280,7 +278,7 @@ sub objectify {
             :                     $self->undefify;
     }
 
-    return subst(
+    return String::Tools::subst(
         $object_str,
         class_str => $self->stringify($class),
         class     => $class,
@@ -338,7 +336,7 @@ sub _scalarify {
               $ref2 eq 'GLOB'    ? $self->globify($_)
             : $ref2 eq 'LVALUE'  ? $self->lvalueify($_)
             : $ref2 eq 'VSTRING' ? $self->vstringify($_)
-            : $ref2 eq 'SCALAR' && Scalar::Util::looks_like_number($_)
+            : $ref2 eq 'SCALAR' && LooksLike::number($_)
                                  ? $self->numify($_)
             :                      $self->stringify($_)
             ;
@@ -426,7 +424,7 @@ __PACKAGE__->set(
 package
     Jasonify::Literal;
 
-use Scalar::Util ();    #qw( looks_like_number );
+use LooksLike ();    #qw( zero );
 
 use overload
     'bool' => 'bool',
@@ -469,13 +467,13 @@ sub bool {
         && $literal ne $$false
         && $literal ne '""'
         && $literal ne '"0"'
-        && !( Scalar::Util::looks_like_number($literal) && $literal == 0 );
+        && !LooksLike::zero($literal);
 }
 
 package
     Jasonify::Number;
 
-use Scalar::Util ();    #qw( looks_like_number );
+use LooksLike ();    #qw( number numeric representation );
 
 use overload
     '0+'  => 'as_num',
@@ -522,14 +520,14 @@ sub number {
     my $class = &Datify::class;
     my $num   = shift;
     Carp::croak( "Not a number ", $num )
-        unless ( Scalar::Util::looks_like_number($num) );
+        unless ( LooksLike::number($num) );
 
     return
-          not( defined( $num <=> 0 ) ) ? $nan
-        : $num ==  'Infinity'          ? $inf
-        : $num == '-Infinity'          ? $ninf
-        : $num =~ /\A$number_regex\z/  ? $class->new($num)
-        :   Carp::croak( "Malformed number ", $num );
+          LooksLike::numeric($num)
+        ? $num =~ /\A$number_regex\z/
+            ? $class->new($num)
+            : Carp::croak( "Malformed number ", $num )
+        : LooksLike::representation($num);
 }
 
 sub formatted { return shift()->number( sprintf( shift(), @_ ) ) }
@@ -998,7 +996,7 @@ L<JSON>, L<Datify>
 
 =head1 VERSION
 
-This document describes version v0.20.052 of this module.
+This document describes version v0.20.060 of this module.
 
 =head1 AUTHOR
 
